@@ -114,7 +114,8 @@ class AutoClickAndEditFormView(EntityView):
                     reload=False, # controls reloading the whole page after change
                                   # boolean, eid (to redirect), or
                                   # function taking the subject entity & returning a boolean or an eid
-                    action=None):
+                    action=None,
+                    **kwargs):    # 'reledit' derivatives forward compatibility
         """display field to edit entity's `rtype` relation on click"""
         assert rtype
         self._cw.add_css('cubicweb.form.css')
@@ -125,14 +126,14 @@ class AutoClickAndEditFormView(EntityView):
         reload = self._compute_reload(rschema, role, reload)
         divid = build_divid(rtype, role, self.entity.eid)
         if rschema.final:
-            self._handle_attribute(rschema, role, divid, reload, action)
+            self._handle_attribute(rschema, role, divid, reload, action, kwargs)
         else:
             if self._is_composite():
-                self._handle_composite(rschema, role, divid, reload, action)
+                self._handle_composite(rschema, role, divid, reload, action, kwargs)
             else:
-                self._handle_relation(rschema, role, divid, reload, action)
+                self._handle_relation(rschema, role, divid, reload, action, kwargs)
 
-    def _handle_attribute(self, rschema, role, divid, reload, action):
+    def _handle_attribute(self, rschema, role, divid, reload, action, kwargs):
         rvid = self._rules.get('rvid', None)
         if rvid is not None:
             value = self._cw.view(rvid, entity=self.entity,
@@ -145,7 +146,8 @@ class AutoClickAndEditFormView(EntityView):
         value = value or self._compute_default_value(rschema, role)
         form_handler = self._cw.vreg['reledit'].select('relation-form-handler', self._cw,
                                                        entity=self.entity, rtype=rschema.type)
-        form_handler.apply(self.w, value, self.entity, rschema, role, divid, reload, action)
+        form_handler.apply(self.w, value, self.entity, rschema, role, divid, reload, action,
+                           extradata=kwargs)
 
     def _compute_value_editperm(self, rschema, role, rvid, **viewargs):
         related_rset = self.entity.related(rschema.type, role)
@@ -155,7 +157,7 @@ class AutoClickAndEditFormView(EntityView):
             value = self._compute_default_value(rschema, role)
         return value, self._should_edit_relation(rschema, role)
 
-    def _handle_relation(self, rschema, role, divid, reload, action):
+    def _handle_relation(self, rschema, role, divid, reload, action, kwargs):
         rvid = self._rules.get('rvid', 'autolimited')
         value, permission = self._compute_value_editperm(rschema, role, rvid)
         if not permission:
@@ -163,19 +165,21 @@ class AutoClickAndEditFormView(EntityView):
         form_handler = self._cw.vreg['reledit'].select('relation-form-handler', self._cw,
                                                        entity=self.entity, rtype=rschema.type)
         form_handler.apply(self.w, value, self.entity, rschema, role, divid,
-                           reload, action)
+                           reload, action, extradata=kwargs)
 
-    def _handle_composite(self, rschema, role, divid, reload, action):
+    def _handle_composite(self, rschema, role, divid, reload, action, kwargs):
         rvid = self._rules.get('rvid', 'edit-related-entity')
         value, permission = self._compute_value_editperm(rschema, role, rvid,
                                                          reload=reload, action=action,
                                                          container=self.entity.eid,
                                                          topleveldiv=divid,
                                                          rtype=rschema.type)
+
         form_handler = self._cw.vreg['reledit'].select('relation-form-handler', self._cw,
                                                        entity=self.entity, rtype=rschema.type)
         form_handler.apply(self.w, value, self.entity, rschema, role, divid,
-                           reload, action, self._may_add_related(rschema, role), False)
+                           reload, action, self._may_add_related(rschema, role), False,
+                           extradata=kwargs)
 
     def _compute_reload(self, rschema, role, reload):
         ctrl_reload = self._rules.get('reload', reload)
@@ -412,7 +416,7 @@ class ReleditRelationFormHandler(ReleditFormHandler):
               add_related=False, edit_rtype=True, extradata=None, **formargs):
         self.w = w
         form, renderer = self._build_form(entity, rschema, role, divid, reload, action,
-                                          extradata=None, **formargs)
+                                          extradata=extradata, **formargs)
         self.view_form(divid, value, form, renderer, add_related, edit_rtype)
 
     def _build_add_zone(self):
